"use strict";

exports.__esModule = true;
exports.createChaos = createChaos;

var _linearInterpolation = require("./linearInterpolation");

function createChaos() {
  var level = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 5;
  var errorMessage = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "🐵 CHAOS 🐵";
  var runInProduction = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

  if (process.env.NODE_ENV === 'production' && !runInProduction) {
    /** Chaos will not occur in production. */
    return false;
  }

  if (typeof level !== 'number') {
    throw new Error('Please provide a number level. You provided string');
  }

  var chaosLevel = level !== 5 ? convertChaosLevel(level) : 0.5;
  var chaosOn = Math.random() >= chaosLevel;
  if (chaosOn) {
    throw new Error(errorMessage);
  }
  return false;
}

function convertChaosLevel(level) {
  if (typeof level !== 'number') {
    throw new Error("Unable to read your chaos level, please only pass in an integer between 1 and 10.");
  }

  if (level === 10) {
    level = .95;
  } else {
    level = (level / 10).toFixed(2);
  }

  return (0, _linearInterpolation.interpolate)(1, 0, level);
}